"""
Version information for NetworkX, created during installation.

Do not add this file to the repository.

"""

import datetime

version = '1.6'
date = 'Tue Nov 22 07:15:35 2011'

# Was NetworkX built from a development version? If so, remember that the major
# and minor versions reference the "target" (rather than "current") release.
dev = False

# Format: (name, major, min, revision)
version_info = ('networkx', 1, 6, '2049c85eac50')

# Format: a 'datetime.datetime' instance
date_info = datetime.datetime(2011, 11, 22, 7, 15, 35, 408614)

# Format: (vcs, vcs_tuple)
vcs_info = ('mercurial', ('2049c85eac50', 'tip'))

